"""
Useful functions and utilities for
logging information about install
"""
import traceback
import analytics
import platform
import getpass

analytics.write_key = '6I7ptc5wcIGC4WZ0N1t0NXvvAbjRGUgX' 

from mitoinstaller import __version__
from mitoinstaller.user_install import get_static_user_id, user_json_only_has_static_user_id

def identify():
    """
    This identify call identifies the user in our logs. Note that
    we make sure that the actual identify call only runs when
    the user has a user.json with only a static id, as if we
    have more feilds, then the user has already run the mitosheet.sheet
    call and thus been identified there.
    """
    static_user_id = get_static_user_id()
    operating_system = platform.system()

    if user_json_only_has_static_user_id():
        analytics.identify(
            static_user_id,
            {
                'operating_system': operating_system,
                'version_installer': __version__,
                'user': getpass.getuser()
            }
        )

def log_step_failed(install_or_upgrade, package, reason):
    # First, we print the traceback, to make live debugging easier
    print(traceback.format_exc())
    # Then, we log it
    log(
        f'{install_or_upgrade}_failed_{package}',
        {  
            'package': package,
            'reason': reason, 
            'error_traceback': traceback.format_exc().split('\n')
        }
    )

def log(event, params=None):
    """
    A utility that all logging should pass through
    """
    static_user_id = get_static_user_id()

    if params is None:
        params = {}

    analytics.track(
        static_user_id, 
        event, 
        params
    )
